"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = {
    swagger: "2.0",
    info: {
        version: "v1",
        title: "TodayApp.Api",
    },
    host: "today.rocketmakers.net:80",
    schemes: ["http"],
    paths: {
        "/api/account/UserInfo": {
            get: {
                tags: ["Account"],
                operationId: "Account_GetUserInfo",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/UserInfoResponse",
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/account/Logout": {
            post: {
                tags: ["Account"],
                operationId: "Account_Logout",
                consumes: [],
                produces: [],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/Void",
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/account/ChangePassword": {
            post: {
                tags: ["Account"],
                operationId: "Account_ChangePassword",
                consumes: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                    "application/x-www-form-urlencoded",
                ],
                produces: [],
                parameters: [
                    {
                        name: "model",
                        in: "body",
                        required: true,
                        schema: {
                            $ref: "#/definitions/ChangePasswordBindingModel",
                        },
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/Void",
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/account/SetPassword": {
            post: {
                tags: ["Account"],
                operationId: "Account_SetPassword",
                consumes: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                    "application/x-www-form-urlencoded",
                ],
                produces: [],
                parameters: [
                    {
                        name: "model",
                        in: "body",
                        required: true,
                        schema: {
                            $ref: "#/definitions/SetPasswordBindingModel",
                        },
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/Void",
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/account/AddClaim": {
            post: {
                tags: ["Account"],
                operationId: "Account_AddClaim",
                consumes: [],
                produces: [],
                parameters: [
                    {
                        name: "userId",
                        in: "query",
                        required: true,
                        type: "string",
                    },
                    {
                        name: "type",
                        in: "query",
                        required: true,
                        type: "string",
                    },
                    {
                        name: "orgId",
                        in: "query",
                        required: true,
                        type: "string",
                    },
                    {
                        name: "divisionId",
                        in: "query",
                        required: false,
                        type: "string",
                    },
                    {
                        name: "itemId",
                        in: "query",
                        required: false,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/Void",
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/account/Register": {
            post: {
                tags: ["Account"],
                operationId: "Account_Register",
                consumes: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                    "application/x-www-form-urlencoded",
                ],
                produces: [],
                parameters: [
                    {
                        name: "model",
                        in: "body",
                        required: true,
                        schema: {
                            $ref: "#/definitions/RegisterBindingModel",
                        },
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/Void",
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/activities": {
            get: {
                tags: ["Activities"],
                summary: "Gets all Activities.",
                operationId: "Activities_GetAll",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "orgId",
                        in: "query",
                        description: "The org identifier.",
                        required: false,
                        type: "string",
                    },
                    {
                        name: "cursor",
                        in: "query",
                        description: "'1:20' = page 1 of 20 items.",
                        required: false,
                        type: "string",
                    },
                    {
                        name: "filter",
                        in: "query",
                        description: "The filter search term",
                        required: false,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            type: "array",
                            items: {
                                $ref: "#/definitions/Activity",
                            },
                        },
                    },
                },
                deprecated: false,
            },
            post: {
                tags: ["Activities"],
                summary: "Creates an event.",
                operationId: "Activities_Post",
                consumes: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                    "application/x-www-form-urlencoded",
                ],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "activity",
                        in: "body",
                        required: true,
                        schema: {
                            $ref: "#/definitions/Activity",
                        },
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/Activity",
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/activities/{id}": {
            get: {
                tags: ["Activities"],
                summary: "Gets the Activity with the specified identifier.",
                operationId: "Activities_Get",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "id",
                        in: "path",
                        description: "The identifier.",
                        required: true,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/Activity",
                        },
                    },
                },
                deprecated: false,
            },
            put: {
                tags: ["Activities"],
                summary: "Updates an event.",
                operationId: "Activities_Put",
                consumes: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                    "application/x-www-form-urlencoded",
                ],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "id",
                        in: "path",
                        required: true,
                        type: "string",
                    },
                    {
                        name: "activity",
                        in: "body",
                        required: true,
                        schema: {
                            $ref: "#/definitions/Activity",
                        },
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/Activity",
                        },
                    },
                },
                deprecated: false,
            },
            delete: {
                tags: ["Activities"],
                summary: "Deletes an activity.",
                operationId: "Activities_Delete",
                consumes: [],
                produces: [],
                parameters: [
                    {
                        name: "id",
                        in: "path",
                        required: true,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/Void",
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/activities/editable": {
            get: {
                tags: ["Activities"],
                summary: "Gets the Activity with the specified identifier.",
                operationId: "Activities_GetEditable",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            type: "array",
                            items: {
                                $ref: "#/definitions/ActivityToken",
                            },
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/activities/{id}/events": {
            get: {
                tags: ["Activities"],
                summary: "Gets the Events for the Activity identifier.",
                operationId: "Activities_GetEvents",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "id",
                        in: "path",
                        description: "The identifier.",
                        required: true,
                        type: "string",
                    },
                    {
                        name: "cursor",
                        in: "query",
                        description: "'1:20' = page 1 of 20 items.",
                        required: false,
                        type: "string",
                    },
                    {
                        name: "filter",
                        in: "query",
                        description: "The filter search term",
                        required: false,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            type: "array",
                            items: {
                                $ref: "#/definitions/ActivityEvent",
                            },
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/version": {
            get: {
                tags: ["ApiVersion"],
                summary: "Gets the Version of the Api.",
                operationId: "ApiVersion_Get",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/ApiVersion",
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/courses": {
            get: {
                tags: ["Course"],
                summary: "Gets all Courses.",
                operationId: "Course_GetAll",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "orgId",
                        in: "query",
                        description: "The org identifier.",
                        required: false,
                        type: "string",
                    },
                    {
                        name: "cursor",
                        in: "query",
                        description: "'1:20' = page 1 of 20 items.",
                        required: false,
                        type: "string",
                    },
                    {
                        name: "filter",
                        in: "query",
                        description: "The filter search term",
                        required: false,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            type: "array",
                            items: {
                                $ref: "#/definitions/CourseToken",
                            },
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/courses/{id}": {
            get: {
                tags: ["Course"],
                summary: "Gets the Course for the specified identifier.",
                operationId: "Course_Get",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "id",
                        in: "path",
                        description: "The identifier.",
                        required: true,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/Course",
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/courses/{id}/classes": {
            get: {
                tags: ["Course"],
                summary: "Gets the Timetable Class for the Course Module identifier.",
                operationId: "Course_GetCourseClasses",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "id",
                        in: "path",
                        description: "The identifier.",
                        required: true,
                        type: "string",
                    },
                    {
                        name: "cursor",
                        in: "query",
                        description: "'1:20' = page 1 of 20 items.",
                        required: false,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            type: "array",
                            items: {
                                $ref: "#/definitions/TimetableClassToken",
                            },
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/courses/modules/{id}/classes": {
            get: {
                tags: ["Course"],
                summary: "Gets the Timetable Class for the Course Module identifier.",
                operationId: "Course_GetCourseModuleClasses",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "id",
                        in: "path",
                        description: "The identifier.",
                        required: true,
                        type: "string",
                    },
                    {
                        name: "cursor",
                        in: "query",
                        description: "'1:20' = page 1 of 20 items.",
                        required: false,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            type: "array",
                            items: {
                                $ref: "#/definitions/TimetableClassToken",
                            },
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/courses/classes/{id}/events": {
            get: {
                tags: ["Course"],
                summary: "Gets the Timetable Class Events for the Timetable Class identifier.",
                operationId: "Course_GetClassEvents",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "id",
                        in: "path",
                        description: "The identifier.",
                        required: true,
                        type: "string",
                    },
                    {
                        name: "cursor",
                        in: "query",
                        description: "'1:20' = page 1 of 20 items.",
                        required: false,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            type: "array",
                            items: {
                                $ref: "#/definitions/TimetableClassEvent",
                            },
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/events": {
            get: {
                tags: ["DatedEvents"],
                summary: "Gets the specified day.",
                operationId: "DatedEvents_Get",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "date",
                        in: "query",
                        description: "The date (e.g. 2015-03-09T18:25:43.511Z).",
                        required: true,
                        type: "string",
                        format: "date-time",
                    },
                    {
                        name: "orgId",
                        in: "query",
                        description: "The org identifier.",
                        required: false,
                        type: "string",
                    },
                    {
                        name: "cursor",
                        in: "query",
                        description: "'1:20' = page 1 of 20 items.",
                        required: false,
                        type: "string",
                    },
                    {
                        name: "filter",
                        in: "query",
                        description: "The filter search term",
                        required: false,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            type: "array",
                            items: {
                                $ref: "#/definitions/IDatedEvent",
                            },
                        },
                    },
                },
                deprecated: false,
            },
            post: {
                tags: ["DatedEvents"],
                summary: "Creates an event.",
                operationId: "DatedEvents_Post",
                consumes: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                    "application/x-www-form-urlencoded",
                ],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "datedEvent",
                        in: "body",
                        required: true,
                        schema: {
                            $ref: "#/definitions/IDatedEvent",
                        },
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/IDatedEvent",
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/events/{id}": {
            get: {
                tags: ["DatedEvents"],
                summary: "Gets the specified identifier.",
                operationId: "DatedEvents_Get",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "id",
                        in: "path",
                        description: "The identifier.",
                        required: true,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/IDatedEvent",
                        },
                    },
                },
                deprecated: false,
            },
            put: {
                tags: ["DatedEvents"],
                summary: "Updates an event.",
                operationId: "DatedEvents_Put",
                consumes: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                    "application/x-www-form-urlencoded",
                ],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "id",
                        in: "path",
                        required: true,
                        type: "string",
                    },
                    {
                        name: "datedEvent",
                        in: "body",
                        required: true,
                        schema: {
                            $ref: "#/definitions/IDatedEvent",
                        },
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/IDatedEvent",
                        },
                    },
                },
                deprecated: false,
            },
            delete: {
                tags: ["DatedEvents"],
                summary: "Deletes an event.",
                operationId: "DatedEvents_Delete",
                consumes: [],
                produces: [],
                parameters: [
                    {
                        name: "id",
                        in: "path",
                        required: true,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/Void",
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/events/counts": {
            get: {
                tags: ["DatedEvents"],
                summary: "Gets the counts.",
                operationId: "DatedEvents_GetCounts",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "date",
                        in: "query",
                        description: "The date (e.g. 2015-03-09T18:25:43.511Z).",
                        required: true,
                        type: "string",
                        format: "date-time",
                    },
                    {
                        name: "numberOfDays",
                        in: "query",
                        description: "The number of days.",
                        required: true,
                        type: "integer",
                        format: "int32",
                    },
                    {
                        name: "orgId",
                        in: "query",
                        description: "The org identifier.",
                        required: false,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            type: "array",
                            items: {
                                $ref: "#/definitions/EventDayStats",
                            },
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/interests": {
            get: {
                tags: ["Interest"],
                summary: "Gets all Interests.",
                operationId: "Interest_GetAll",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "orgId",
                        in: "query",
                        description: "The org identifier.",
                        required: false,
                        type: "string",
                    },
                    {
                        name: "cursor",
                        in: "query",
                        description: "'1:20' = page 1 of 20 items.",
                        required: false,
                        type: "string",
                    },
                    {
                        name: "filter",
                        in: "query",
                        description: "The filter search term",
                        required: false,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            type: "array",
                            items: {
                                $ref: "#/definitions/InterestToken",
                            },
                        },
                    },
                },
                deprecated: false,
            },
            post: {
                tags: ["Interest"],
                summary: "Creates an event.",
                operationId: "Interest_Post",
                consumes: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                    "application/x-www-form-urlencoded",
                ],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "interest",
                        in: "body",
                        required: true,
                        schema: {
                            $ref: "#/definitions/Interest",
                        },
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/Interest",
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/interests/category/{id}": {
            get: {
                tags: ["Interest"],
                summary: "Gets the Interests with the specified Interest Category id.",
                operationId: "Interest_GetByCategory",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "id",
                        in: "path",
                        description: "The interest category identifier.",
                        required: true,
                        type: "string",
                    },
                    {
                        name: "cursor",
                        in: "query",
                        description: "'1:20' = page 1 of 20 items.",
                        required: false,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            type: "array",
                            items: {
                                $ref: "#/definitions/InterestToken",
                            },
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/interests/{id}": {
            get: {
                tags: ["Interest"],
                summary: "Gets the Interest with the specified identifier.",
                operationId: "Interest_Get",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "id",
                        in: "path",
                        description: "The identifier.",
                        required: true,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/Interest",
                        },
                    },
                },
                deprecated: false,
            },
            put: {
                tags: ["Interest"],
                summary: "Updates an event.",
                operationId: "Interest_Put",
                consumes: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                    "application/x-www-form-urlencoded",
                ],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "id",
                        in: "path",
                        required: true,
                        type: "string",
                    },
                    {
                        name: "interest",
                        in: "body",
                        required: true,
                        schema: {
                            $ref: "#/definitions/Interest",
                        },
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/Interest",
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/interests/categories/info": {
            get: {
                tags: ["Interest"],
                summary: "Gets the Interest Categories (based on Users Organisation).",
                operationId: "Interest_GetCategories",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "orgId",
                        in: "query",
                        required: false,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            type: "array",
                            items: {
                                $ref: "#/definitions/InterestCategoryCatalog",
                            },
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/organisations": {
            get: {
                tags: ["Organisation"],
                summary: "Gets all Organisations.",
                operationId: "Organisation_GetAll",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "cursor",
                        in: "query",
                        description: "'1:20' = page 1 of 20 items.",
                        required: false,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            type: "array",
                            items: {
                                $ref: "#/definitions/Organisation",
                            },
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/organisations/{id}": {
            get: {
                tags: ["Organisation"],
                summary: "Gets the Organisation for the specified identifier.",
                operationId: "Organisation_Get",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "id",
                        in: "path",
                        description: "The identifier.",
                        required: true,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/Organisation",
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/organisations/{id}/terms": {
            get: {
                tags: ["Organisation"],
                summary: "Gets the Organisation Terms for the specified identifier.",
                operationId: "Organisation_GetTerms",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "id",
                        in: "path",
                        description: "The identifier.",
                        required: true,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            type: "array",
                            items: {
                                $ref: "#/definitions/OrganisationTerm",
                            },
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/me": {
            get: {
                tags: ["Profile"],
                summary: "Gets the current users Profile.",
                operationId: "Profile_Get",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/Profile",
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/me/registration": {
            get: {
                tags: ["Profile"],
                summary: "Gets the current users Profile.",
                operationId: "Profile_GetRegistration",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            type: "array",
                            items: {
                                $ref: "#/definitions/OrganisationTermRegistration",
                            },
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/me/claims": {
            get: {
                tags: ["Profile"],
                summary: "Gets the current users Profile Claims.",
                operationId: "Profile_GetClaims",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            type: "array",
                            items: {
                                $ref: "#/definitions/ProfileClaim",
                            },
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/me/subscribesync": {
            post: {
                tags: ["Profile"],
                summary: "Create a subscription for the current user.",
                operationId: "Profile_PostSubscribeSync",
                consumes: [
                    "application/json",
                    "text/json",
                    "application/x-www-form-urlencoded",
                ],
                produces: [],
                parameters: [
                    {
                        name: "subscription",
                        in: "body",
                        description: "The subscription.",
                        required: true,
                        schema: {
                            $ref: "#/definitions/SubscriptionChange",
                        },
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/Void",
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/me/subscribe": {
            post: {
                tags: ["Profile"],
                summary: "Create a subscription for the current user.",
                operationId: "Profile_PostSubscribe",
                consumes: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                    "application/x-www-form-urlencoded",
                ],
                produces: [],
                parameters: [
                    {
                        name: "subscription",
                        in: "body",
                        description: "The subscription.",
                        required: true,
                        schema: {
                            $ref: "#/definitions/ISubscription",
                        },
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/Void",
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/me/unsubscribe/{id}": {
            delete: {
                tags: ["Profile"],
                summary: "Deletes the subscription from the current user.",
                operationId: "Profile_DeleteUnsubscribe",
                consumes: [],
                produces: [],
                parameters: [
                    {
                        name: "id",
                        in: "path",
                        description: "The identifier.",
                        required: true,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/Void",
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/me/events": {
            get: {
                tags: ["Profile"],
                summary: "Gets the current users events.",
                operationId: "Profile_GetEvents",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "orgId",
                        in: "query",
                        description: "The org identifier.",
                        required: false,
                        type: "string",
                    },
                    {
                        name: "cursor",
                        in: "query",
                        description: "'1:20' = page 1 of 20 items.",
                        required: false,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            type: "array",
                            items: {
                                $ref: "#/definitions/ProfileEvent",
                            },
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/venues": {
            get: {
                tags: ["Venue"],
                summary: "Gets all Venues.",
                operationId: "Venue_GetAll",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "orgId",
                        in: "query",
                        description: "The org identifier.",
                        required: false,
                        type: "string",
                    },
                    {
                        name: "cursor",
                        in: "query",
                        description: "'1:20' = page 1 of 20 items.",
                        required: false,
                        type: "string",
                    },
                    {
                        name: "filter",
                        in: "query",
                        description: "Simple filter query on venue title",
                        required: false,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            type: "array",
                            items: {
                                $ref: "#/definitions/VenueToken",
                            },
                        },
                    },
                },
                deprecated: false,
            },
            post: {
                tags: ["Venue"],
                summary: "Posts the specified venue.",
                operationId: "Venue_Post",
                consumes: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                    "application/x-www-form-urlencoded",
                ],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "venue",
                        in: "body",
                        description: "The venue.",
                        required: true,
                        schema: {
                            $ref: "#/definitions/Venue",
                        },
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/Venue",
                        },
                    },
                },
                deprecated: false,
            },
        },
        "/api/venues/{id}": {
            get: {
                tags: ["Venue"],
                summary: "Gets the Venue with the specified identifier.",
                operationId: "Venue_Get",
                consumes: [],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "id",
                        in: "path",
                        description: "The identifier.",
                        required: true,
                        type: "string",
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/Venue",
                        },
                    },
                },
                deprecated: false,
            },
            put: {
                tags: ["Venue"],
                summary: "Puts the specified venue.",
                operationId: "Venue_Put",
                consumes: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                    "application/x-www-form-urlencoded",
                ],
                produces: [
                    "application/json",
                    "text/json",
                    "application/xml",
                    "text/xml",
                ],
                parameters: [
                    {
                        name: "id",
                        in: "path",
                        description: "The identifier.",
                        required: true,
                        type: "string",
                    },
                    {
                        name: "venue",
                        in: "body",
                        description: "The venue.",
                        required: true,
                        schema: {
                            $ref: "#/definitions/Venue",
                        },
                    },
                ],
                responses: {
                    "200": {
                        description: "OK",
                        schema: {
                            $ref: "#/definitions/Venue",
                        },
                    },
                },
                deprecated: false,
            },
        },
    },
    definitions: {
        UserInfoResponse: {
            type: "object",
            properties: {
                email: {
                    type: "string",
                },
                hasRegistered: {
                    type: "boolean",
                },
                loginProvider: {
                    type: "string",
                },
            },
        },
        Void: {
            type: "object",
            properties: {},
        },
        ChangePasswordBindingModel: {
            required: ["oldPassword", "newPassword"],
            type: "object",
            properties: {
                oldPassword: {
                    type: "string",
                },
                newPassword: {
                    type: "string",
                },
                confirmPassword: {
                    type: "string",
                },
            },
        },
        SetPasswordBindingModel: {
            required: ["newPassword"],
            type: "object",
            properties: {
                newPassword: {
                    type: "string",
                },
                confirmPassword: {
                    type: "string",
                },
            },
        },
        RegisterBindingModel: {
            required: ["email", "password", "registrationId"],
            type: "object",
            properties: {
                email: {
                    type: "string",
                },
                password: {
                    type: "string",
                },
                confirmPassword: {
                    type: "string",
                },
                registrationId: {
                    type: "string",
                },
            },
        },
        Activity: {
            type: "object",
            properties: {
                orgId: {
                    type: "string",
                },
                divisionId: {
                    type: "string",
                },
                description: {
                    type: "string",
                },
                interestIds: {
                    type: "array",
                    items: {
                        type: "string",
                    },
                },
                id: {
                    type: "string",
                },
                name: {
                    type: "string",
                },
            },
        },
        ActivityToken: {
            type: "object",
            properties: {
                id: {
                    type: "string",
                },
                name: {
                    type: "string",
                },
            },
        },
        ActivityEvent: {
            type: "object",
            properties: {
                type: {
                    type: "string",
                    readOnly: true,
                },
                id: {
                    type: "string",
                },
                subscriptionId: {
                    type: "string",
                },
                venue: {
                    $ref: "#/definitions/VenueToken",
                },
                alternativeVenues: {
                    type: "array",
                    items: {
                        $ref: "#/definitions/VenueToken",
                    },
                },
                title: {
                    type: "string",
                },
                description: {
                    type: "string",
                },
                startDate: {
                    format: "date-time",
                    type: "string",
                },
                endDate: {
                    format: "date-time",
                    type: "string",
                },
                interests: {
                    type: "array",
                    items: {
                        $ref: "#/definitions/InterestToken",
                    },
                },
                duration: {
                    type: "string",
                    readOnly: true,
                },
            },
        },
        VenueToken: {
            type: "object",
            properties: {
                id: {
                    type: "string",
                },
                subscriptionId: {
                    type: "string",
                },
                title: {
                    type: "string",
                },
                latitude: {
                    format: "float",
                    type: "number",
                },
                longitude: {
                    format: "float",
                    type: "number",
                },
                postCode: {
                    type: "string",
                },
            },
        },
        InterestToken: {
            type: "object",
            properties: {
                id: {
                    type: "string",
                },
                name: {
                    type: "string",
                },
                category: {
                    type: "string",
                },
            },
        },
        ApiVersion: {
            type: "object",
            properties: {
                major: {
                    format: "int32",
                    type: "integer",
                },
                minor: {
                    format: "int32",
                    type: "integer",
                },
                revision: {
                    format: "int32",
                    type: "integer",
                },
                build: {
                    format: "int32",
                    type: "integer",
                },
            },
        },
        CourseToken: {
            type: "object",
            properties: {
                id: {
                    type: "string",
                },
                title: {
                    type: "string",
                },
                description: {
                    type: "string",
                },
                level: {
                    type: "string",
                },
                year: {
                    type: "string",
                },
                department: {
                    type: "string",
                },
            },
        },
        Course: {
            type: "object",
            properties: {
                orgId: {
                    type: "string",
                },
                divisionId: {
                    type: "string",
                },
                organisationTermId: {
                    type: "string",
                },
                calendarId: {
                    type: "string",
                },
                courseModuleIds: {
                    type: "array",
                    items: {
                        $ref: "#/definitions/CourseModule",
                    },
                },
                id: {
                    type: "string",
                },
                title: {
                    type: "string",
                },
                description: {
                    type: "string",
                },
                level: {
                    type: "string",
                },
                year: {
                    type: "string",
                },
                department: {
                    type: "string",
                },
            },
        },
        CourseModule: {
            type: "object",
            properties: {
                id: {
                    type: "string",
                },
                title: {
                    type: "string",
                },
                description: {
                    type: "string",
                },
                semester: {
                    type: "string",
                },
            },
        },
        TimetableClassToken: {
            type: "object",
            properties: {
                id: {
                    type: "string",
                },
                title: {
                    type: "string",
                },
                description: {
                    type: "string",
                },
                isOptional: {
                    type: "boolean",
                },
            },
        },
        TimetableClassEvent: {
            type: "object",
            properties: {
                courseIds: {
                    type: "array",
                    items: {
                        type: "string",
                    },
                },
                type: {
                    type: "string",
                    readOnly: true,
                },
                isOptional: {
                    type: "boolean",
                },
                id: {
                    type: "string",
                },
                subscriptionId: {
                    type: "string",
                },
                venue: {
                    $ref: "#/definitions/VenueToken",
                },
                alternativeVenues: {
                    type: "array",
                    items: {
                        $ref: "#/definitions/VenueToken",
                    },
                },
                title: {
                    type: "string",
                },
                description: {
                    type: "string",
                },
                startDate: {
                    format: "date-time",
                    type: "string",
                },
                endDate: {
                    format: "date-time",
                    type: "string",
                },
                interests: {
                    type: "array",
                    items: {
                        $ref: "#/definitions/InterestToken",
                    },
                },
                duration: {
                    type: "string",
                    readOnly: true,
                },
            },
        },
        IDatedEvent: {
            type: "object",
            properties: {
                description: {
                    type: "string",
                },
                type: {
                    type: "string",
                    readOnly: true,
                },
                duration: {
                    type: "string",
                    readOnly: true,
                },
            },
        },
        EventDayStats: {
            type: "object",
            properties: {
                date: {
                    format: "date-time",
                    type: "string",
                },
                count: {
                    format: "int32",
                    type: "integer",
                },
            },
        },
        Interest: {
            type: "object",
            properties: {
                isMandatory: {
                    type: "boolean",
                },
                orgId: {
                    type: "string",
                },
                interestCategoryId: {
                    type: "string",
                },
                id: {
                    type: "string",
                },
                name: {
                    type: "string",
                },
                category: {
                    type: "string",
                },
            },
        },
        InterestCategoryCatalog: {
            type: "object",
            properties: {
                id: {
                    type: "string",
                },
                orgId: {
                    type: "string",
                },
                categories: {
                    type: "array",
                    items: {
                        $ref: "#/definitions/InterestCategory",
                    },
                },
            },
        },
        InterestCategory: {
            type: "object",
            properties: {
                id: {
                    type: "string",
                },
                name: {
                    type: "string",
                },
                url: {
                    type: "string",
                },
            },
        },
        Organisation: {
            type: "object",
            properties: {
                id: {
                    type: "string",
                },
                name: {
                    type: "string",
                },
                divisions: {
                    type: "array",
                    items: {
                        $ref: "#/definitions/Division",
                    },
                },
            },
        },
        Division: {
            type: "object",
            properties: {
                id: {
                    type: "string",
                },
                name: {
                    type: "string",
                },
                hasCourse: {
                    type: "boolean",
                },
                hasActivity: {
                    type: "boolean",
                },
            },
        },
        OrganisationTerm: {
            type: "object",
            properties: {
                id: {
                    type: "string",
                },
                name: {
                    type: "string",
                },
                orgId: {
                    type: "string",
                },
                startDate: {
                    format: "date-time",
                    type: "string",
                },
                endDate: {
                    format: "date-time",
                    type: "string",
                },
            },
        },
        Profile: {
            type: "object",
            properties: {
                id: {
                    type: "string",
                },
                firstName: {
                    type: "string",
                },
                lastName: {
                    type: "string",
                },
            },
        },
        OrganisationTermRegistration: {
            type: "object",
            properties: {
                id: {
                    type: "string",
                },
                profileId: {
                    type: "string",
                },
                organisationTermId: {
                    type: "string",
                },
                subscriptions: {
                    type: "array",
                    items: {
                        $ref: "#/definitions/ISubscription",
                    },
                },
            },
        },
        ISubscription: {
            type: "object",
            properties: {
                type: {
                    type: "string",
                    readOnly: true,
                },
            },
        },
        ProfileClaim: {
            type: "object",
            properties: {
                type: {
                    type: "string",
                },
                ids: {
                    type: "array",
                    items: {
                        type: "string",
                    },
                },
            },
        },
        SubscriptionChange: {
            type: "object",
            properties: {
                added: {
                    type: "array",
                    items: {
                        $ref: "#/definitions/ISubscription",
                    },
                    readOnly: true,
                },
                removed: {
                    type: "array",
                    items: {
                        $ref: "#/definitions/ISubscription",
                    },
                    readOnly: true,
                },
            },
        },
        ProfileEvent: {
            type: "object",
            properties: {
                type: {
                    type: "string",
                    readOnly: true,
                },
                id: {
                    type: "string",
                },
                subscriptionId: {
                    type: "string",
                },
                venue: {
                    $ref: "#/definitions/VenueToken",
                },
                alternativeVenues: {
                    type: "array",
                    items: {
                        $ref: "#/definitions/VenueToken",
                    },
                },
                title: {
                    type: "string",
                },
                description: {
                    type: "string",
                },
                startDate: {
                    format: "date-time",
                    type: "string",
                },
                endDate: {
                    format: "date-time",
                    type: "string",
                },
                interests: {
                    type: "array",
                    items: {
                        $ref: "#/definitions/InterestToken",
                    },
                },
                duration: {
                    type: "string",
                    readOnly: true,
                },
            },
        },
        Venue: {
            type: "object",
            properties: {
                orgId: {
                    type: "string",
                },
                address1: {
                    type: "string",
                },
                address2: {
                    type: "string",
                },
                city: {
                    type: "string",
                },
                county: {
                    type: "string",
                },
                id: {
                    type: "string",
                },
                subscriptionId: {
                    type: "string",
                },
                title: {
                    type: "string",
                },
                latitude: {
                    format: "float",
                    type: "number",
                },
                longitude: {
                    format: "float",
                    type: "number",
                },
                postCode: {
                    type: "string",
                },
            },
        },
    },
};
