"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("underscore");
const contentBuilder_1 = require("./contentBuilder");
exports.TypeNamespaceName = "Api";
exports.TypeNamespace = exports.TypeNamespaceName + ".";
class TypeResolver {
    static getRefType(owner) {
        return owner.$ref
            ? contentBuilder_1.ContentBuilder.toTypeName(owner.$ref.substring(14))
            : null;
    }
    static getType(def, itemsParent) {
        if (!def) {
            return "IErrorTypeNotFound";
        }
        if (def.enum) {
            let enumName = def["enumName"];
            if (!enumName && itemsParent) {
                enumName = itemsParent["enumName"];
            }
            let enumMembers = def["enumMembers"];
            if (!enumMembers && itemsParent) {
                enumMembers = itemsParent["enumMembers"];
            }
            if (enumName && enumMembers) {
                TypeResolver.enumTypes[enumName] = enumMembers;
                return exports.TypeNamespace + enumName + " /* enum */";
            }
            if (def.format === "int32") {
                const enumInts = def["enum"];
                if (enumInts && Array.isArray(enumInts)) {
                    return `${enumInts.join(" | ")} /* enum */`;
                }
            }
            const enumStrings = def["enum"];
            if (enumStrings && Array.isArray(enumStrings)) {
                return `"${enumStrings.join(`" | "`)}" /* enum */`;
            }
            return "number /* enum */";
        }
        var t = def.type;
        if (!t) {
            var r = TypeResolver.getRefType(def);
            if (!r) {
                return "any";
            }
            if (r === "Guid") {
                return `string /* GUID */`;
            }
            return exports.TypeNamespace + r;
        }
        if (t === "integer") {
            t = "number /* integer */";
        }
        if (t === "object") {
            t = "any /* object */";
        }
        return t;
    }
    static getItemType(def) {
        if (_.isArray(def.items)) {
            return def.items.map((i) => TypeResolver.getType(i, def)).join("|");
        }
        return TypeResolver.getType(def.items, def);
    }
    static getPropertyType(def) {
        var type = TypeResolver.getType(def);
        if (type === "array") {
            type = TypeResolver.getItemType(def) + "[]";
        }
        return type;
    }
}
TypeResolver.enumTypes = {};
exports.TypeResolver = TypeResolver;
